

set -ex



test -L $PREFIX/lib/libcufft.so
test -L $PREFIX/lib/libcufftw.so
test -f $PREFIX/targets/sbsa-linux/include/cudalibxt.h
test -f $PREFIX/targets/sbsa-linux/include/cufft.h
test -f $PREFIX/targets/sbsa-linux/include/cufftw.h
test -f $PREFIX/targets/sbsa-linux/include/cufftXt.h
test -L $PREFIX/targets/sbsa-linux/lib/libcufft.so
test -L $PREFIX/targets/sbsa-linux/lib/libcufftw.so
test -f $PREFIX/targets/sbsa-linux/lib/stubs/libcufft.so
test -f $PREFIX/targets/sbsa-linux/lib/stubs/libcufftw.so
exit 0
